@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2017, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -12,7 +12,7 @@
 
 static PetscBool MFNPackageInitialized = PETSC_FALSE;
 
-const char *const MFNConvergedReasons_Shifted[] = {"DIVERGED_BREAKDOWN","DIVERGED_ITS","CONVERGED_ITERATING","CONVERGED_TOL","CONVERGED_ITS","MFNConvergedReason","MFN_",0};
+const char *const MFNConvergedReasons_Shifted[] = {"DIVERGED_BREAKDOWN","DIVERGED_ITS","CONVERGED_ITERATING","CONVERGED_TOL","CONVERGED_ITS","MFNConvergedReason","MFN_",NULL};
 const char *const*MFNConvergedReasons = MFNConvergedReasons_Shifted + 2;
 
 /*@C
@@ -25,12 +25,14 @@ const char *const*MFNConvergedReasons = MFNConvergedReasons_Shifted + 2;
 @*/
 PetscErrorCode MFNFinalizePackage(void)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscFunctionListDestroy(&MFNList);CHKERRQ(ierr);
-  MFNPackageInitialized = PETSC_FALSE;
-  MFNRegisterAllCalled  = PETSC_FALSE;
+  PetscCall(PetscFunctionListDestroy(&MFNList));
+  PetscCall(PetscFunctionListDestroy(&MFNMonitorList));
+  PetscCall(PetscFunctionListDestroy(&MFNMonitorCreateList));
+  PetscCall(PetscFunctionListDestroy(&MFNMonitorDestroyList));
+  MFNPackageInitialized       = PETSC_FALSE;
+  MFNRegisterAllCalled        = PETSC_FALSE;
+  MFNMonitorRegisterAllCalled = PETSC_FALSE;
   PetscFunctionReturn(0);
 }
 
@@ -46,37 +48,32 @@ PetscErrorCode MFNFinalizePackage(void)
 PetscErrorCode MFNInitializePackage(void)
 {
   char           logList[256];
-  char           *className;
-  PetscBool      opt;
-  PetscErrorCode ierr;
+  PetscBool      opt,pkg;
+  PetscClassId   classids[1];
 
   PetscFunctionBegin;
   if (MFNPackageInitialized) PetscFunctionReturn(0);
   MFNPackageInitialized = PETSC_TRUE;
   /* Register Classes */
-  ierr = PetscClassIdRegister("Matrix Function",&MFN_CLASSID);CHKERRQ(ierr);
+  PetscCall(PetscClassIdRegister("Matrix Function",&MFN_CLASSID));
   /* Register Constructors */
-  ierr = MFNRegisterAll();CHKERRQ(ierr);
+  PetscCall(MFNRegisterAll());
+  /* Register Monitors */
+  PetscCall(MFNMonitorRegisterAll());
   /* Register Events */
-  ierr = PetscLogEventRegister("MFNSetUp",MFN_CLASSID,&MFN_SetUp);CHKERRQ(ierr);
-  ierr = PetscLogEventRegister("MFNSolve",MFN_CLASSID,&MFN_Solve);CHKERRQ(ierr);
-  /* Process info exclusions */
-  ierr = PetscOptionsGetString(NULL,NULL,"-info_exclude",logList,256,&opt);CHKERRQ(ierr);
-  if (opt) {
-    ierr = PetscStrstr(logList,"mfn",&className);CHKERRQ(ierr);
-    if (className) {
-      ierr = PetscInfoDeactivateClass(MFN_CLASSID);CHKERRQ(ierr);
-    }
-  }
+  PetscCall(PetscLogEventRegister("MFNSetUp",MFN_CLASSID,&MFN_SetUp));
+  PetscCall(PetscLogEventRegister("MFNSolve",MFN_CLASSID,&MFN_Solve));
+  /* Process Info */
+  classids[0] = MFN_CLASSID;
+  PetscCall(PetscInfoProcessClass("mfn",1,&classids[0]));
   /* Process summary exclusions */
-  ierr = PetscOptionsGetString(NULL,NULL,"-log_exclude",logList,256,&opt);CHKERRQ(ierr);
+  PetscCall(PetscOptionsGetString(NULL,NULL,"-log_exclude",logList,sizeof(logList),&opt));
   if (opt) {
-    ierr = PetscStrstr(logList,"mfn",&className);CHKERRQ(ierr);
-    if (className) {
-      ierr = PetscLogEventDeactivateClass(MFN_CLASSID);CHKERRQ(ierr);
-    }
+    PetscCall(PetscStrInList("mfn",logList,',',&pkg));
+    if (pkg) PetscCall(PetscLogEventDeactivateClass(MFN_CLASSID));
   }
-  ierr = PetscRegisterFinalize(MFNFinalizePackage);CHKERRQ(ierr);
+  /* Register package finalizer */
+  PetscCall(PetscRegisterFinalize(MFNFinalizePackage));
   PetscFunctionReturn(0);
 }
 
@@ -88,13 +85,10 @@ PetscErrorCode MFNInitializePackage(void)
   This one registers all the MFN methods that are in the basic SLEPc libslepcmfn
   library.
  */
-PETSC_EXTERN PetscErrorCode PetscDLLibraryRegister_slepcmfn()
+SLEPC_EXTERN PetscErrorCode PetscDLLibraryRegister_slepcmfn()
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = MFNInitializePackage();CHKERRQ(ierr);
+  PetscCall(MFNInitializePackage());
   PetscFunctionReturn(0);
 }
 #endif /* PETSC_HAVE_DYNAMIC_LIBRARIES */
-
